@@ -1,11 +1,13 @@
 # __main__.py
 
 import blab
+from importlib.metadata import version
 
 def main():
-    print('blab Hello World')
+    print('Hello blab', version('blab') )
 
     
+    
 if __name__ == "__main__":
     main()    
     
